#!/bin/sh
# tmda 0.57 setup script
# 06/24/02 jsm initial creation
# 06/25/02 jon additions and fixes and checks

# notify root
id=`id -un`
date=`date`
mail -s "new tmda setup" root <<EOM
Hey, $id ran $0 at $date.
EOM


cd

echo "Configure procmail.. Begin."
if [ -d ~/.procmail/ ]; then
  echo "[-]  ~/.procmail/ directory exists, check files manually."
else
  mkdir ~/.procmail/
  echo "[X]  ~/.procmail/ directory is set up now."
fi

# ~/.procmail exists now
touch .procmail/rc.kill
touch .procmail/rc.lists
cp /usr/local/share/doc/tmda/contrib/rupture.procmail.tmda.rc .procmail/rc.tmda

if [ -f .procmailrc ]; then
  echo "[-]  ~/.procmailrc exists, check its contents manually."
else
  cp /usr/local/share/doc/procmail/contrib/rupture.procmailrc .procmailrc
  perl -pi -e 's/^#INCLUDERC=\$PMDIR\/rc.tmda/INCLUDERC=\$PMDIR\/rc.tmda/' .procmailrc
  echo "[X]  ~/.procmailrc is set up now."
fi
echo "Configure procmail.. Done."

echo "Configure TMDA.. Begin."

echo 'DEFAULT=$HOME/mbox' > .procmailrc-tmda
mkdir -p ~/.tmda/lists
mkdir -p ~/.tmda/filters
mkdir -p ~/.tmda/logs
mkdir -p ~/.tmda/templates
touch ~/.tmda/lists/blacklist
touch ~/.tmda/lists/whitelist
touch ~/.tmda/lists/whitelist_confirmed
touch ~/.tmda/lists/whitelist_wildcards
cp /usr/local/share/doc/tmda/contrib/rupture.config ~/.tmda/config
cp /usr/local/share/doc/tmda/contrib/README.TEMPLATES ~/.tmda/templates/README

N=`eval grep ^$USER: /etc/passwd| awk -F: '{print $5}'`
perl -pi -e "s/^# FULLNAME(.*)/FULLNAME = \"$N\"/" ~/.tmda/config
perl -pi -e "s/^# CONFIRM_ADDRESS(.*)/CONFIRM_ADDRESS = \"$USER\@rupture.net\"/" ~/.tmda/config

chmod 600 ~/.tmda/config
tmda-keygen -b > ~/.tmda/crypt_key
chmod 600 ~/.tmda/crypt_key
cp /usr/local/share/doc/tmda/contrib/rupture.incoming ~/.tmda/filters/incoming
cp /usr/local/share/doc/tmda/contrib/rupture.outgoing ~/.tmda/filters/outgoing

echo "Configure TMDA.. Done."

if [ -f ~/.forward ]; then
  mv ~/.forward ~/.forward.crap
  echo "~/.forward file found and backed up to ~/.forward.crap"
fi

# tmda >= 0.77 autocleans and does not need cron to delete
echo "Configure cron job for tmda-pending.. Begin."
crontab -l > /tmp/$USER.tmda.xxx
grep -q tmda-pending /tmp/$USER.tmda.xxx
ALRCRON=$?
if [ $ALRCRON = "1" ]; then   #  1 = false, so add to crontab
K=`tmda-address -k summary`	# keyword addy for summary reports
cat << EOCRON >> /tmp/$USER.tmda.xxx
PATH="/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/bin:/home/$USER/bin"
# 30 3 * * * tmda-pending -q -b -d -O 14d
30 15 * * * tmda-pending -C -b -s | mail -E -s 'TMDA pending summary' $K > /dev/null 2>&1
EOCRON
echo "[X]  Cron job set."
else
  echo "[-]  Cron job already set."
fi
crontab /tmp/$USER.tmda.xxx
rm /tmp/$USER.tmda.xxx
echo "Configure cron job for tmda-pending.. Done."
echo ""
echo "****************************************************************"
echo "Be sure to read the documentation at:"
echo "http://www.rupture.net/tmda/"
echo ""
echo "All the files and scripts to use TMDA have been set up for you."
echo "TMDA is now protecting your inbox from spam."
echo "You might want to add email addresses to your ~/.tmda/lists/whitelist ."
echo "You can do this manually or use the collectaddys script as described in"
echo "the online documentation."
echo "Email admin@rupture.net with specific questions etc."
echo ""
#EOF

